@@ -1,4 +1,3 @@
-pref("security.enable_ssl2",             false);
 pref("security.enable_ssl3",             true);
 pref("security.enable_tls",		 true);
 pref("security.enable_tls_session_tickets", true);
@@ -10,12 +9,6 @@ pref("security.ssl.require_safe_negotiation",  false);
 pref("security.ssl.warn_missing_rfc5746",  1);
 pref("security.ssl.enable_false_start", false);
 
-pref("security.ssl2.rc4_128", false);
-pref("security.ssl2.rc2_128", false);
-pref("security.ssl2.des_ede3_192", false);
-pref("security.ssl2.des_64", false);
-pref("security.ssl2.rc4_40", false);
-pref("security.ssl2.rc2_40", false);
 pref("security.ssl3.rsa_rc4_128_md5", true);
 pref("security.ssl3.rsa_rc4_128_sha", true);
 pref("security.ssl3.rsa_fips_des_ede3_sha", true);
@@ -145,18 +138,22 @@ pref("browser.cache.disk.smart_size.first_run", true);
 // Does the user want smart-sizing?
 pref("browser.cache.disk.smart_size.enabled", true);
 // Size explicitly set by the user. Used when smart_size.enabled == false
-//@line 69 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("browser.cache.disk.capacity",         256000);
-//@line 73 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+// User-controllable max-size for entries in disk-cache. Regardless of this
+// setting, no entries bigger than 1/8 of disk-cache will be cached
+pref("browser.cache.disk.max_entry_size",    5120);
 pref("browser.cache.memory.enable",         true);
-//pref("browser.cache.memory.capacity",     -1);
 // -1 = determine dynamically, 0 = none, n = memory capacity in kilobytes
+//pref("browser.cache.memory.capacity",     -1);
+// User-controllable max-size for entries in mem-cache. Regardless of this
+// setting, no entries bigger than 90% of the mem-cache will be cached
+pref("browser.cache.memory.max_entry_size",  5120);
 pref("browser.cache.disk_cache_ssl",        true);
 // 0 = once-per-session, 1 = each-time, 2 = never, 3 = when-appropriate/automatically
 pref("browser.cache.check_doc_frequency",   3);
 
 pref("browser.cache.offline.enable",           true);
-//@line 82 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+
 // offline cache capacity in kilobytes
 pref("browser.cache.offline.capacity",         512000);
 
@@ -167,21 +164,25 @@ pref("offline-apps.quota.max",        204800);
 // the user should be warned if offline app disk usage exceeds this amount
 // (in kilobytes)
 pref("offline-apps.quota.warn",        51200);
-//@line 98 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether or not indexedDB is enabled.
 pref("dom.indexedDB.enabled", true);
 // Space to allow indexedDB databases before prompting (in MB).
 pref("dom.indexedDB.warningQuota", 50);
 
+// Whether or not Web Workers are enabled.
+pref("dom.workers.enabled", true);
+// The number of workers per domain allowed to run concurrently.
+pref("dom.workers.maxPerDomain", 20);
+
+// Whether window.performance is enabled
+pref("dom.enable_performance", true);
+
 // Fastback caching - if this pref is negative, then we calculate the number
 // of content viewers to cache based on the amount of available memory.
 pref("browser.sessionhistory.max_total_viewers", -1);
 
-pref("browser.sessionhistory.optimize_eviction", true);
-
 pref("ui.use_native_colors", true);
-pref("ui.use_native_popup_windows", false);
 pref("ui.click_hold_context_menus", false);
 pref("browser.display.use_document_fonts",  1);  // 0 = never, 1 = quick, 2 = always
 pref("browser.display.use_document_colors", true);
@@ -245,13 +246,13 @@ pref("media.cache_size", 512000);
 // Master HTML5 media volume scale.
 pref("media.volume_scale", "1.0");
 
-//@line 179 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 180 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.ogg.enabled", true);
-//@line 182 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 183 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.wave.enabled", true);
-//@line 185 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 186 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("media.webm.enabled", true);
-//@line 187 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 188 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to autostart a media element with an |autoplay| attribute
 pref("media.autoplay.enabled", true);
@@ -261,28 +262,31 @@ pref("media.autoplay.enabled", true);
 pref("gfx.color_management.mode", 2);
 pref("gfx.color_management.display_profile", "");
 pref("gfx.color_management.rendering_intent", 0);
+pref("gfx.color_management.enablev4", false);
 
 pref("gfx.downloadable_fonts.enabled", true);
 pref("gfx.downloadable_fonts.fallback_delay", 3000);
 pref("gfx.downloadable_fonts.sanitize", true);
 
 // see gfx/thebes/gfxUnicodeProperties.h for definitions of script bits
-//@line 203 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
-// use harfbuzz for default (0x01) + arabic (0x02) + hebrew (0x04)
-pref("gfx.font_rendering.harfbuzz.scripts", 7);
-//@line 209 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 205 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+// use harfbuzz for default (0x01) + arabic (0x02) + hebrew (0x04) + thai (0x40)
+pref("gfx.font_rendering.harfbuzz.scripts", 71);
+//@line 211 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 //@line 216 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
+//@line 220 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+
 pref("accessibility.browsewithcaret", false);
 pref("accessibility.warn_on_browsewithcaret", true);
 
 pref("accessibility.browsewithcaret_shortcut.enabled", true);
 
-//@line 240 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 244 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 // Only on mac tabfocus is expected to handle UI widgets as well as web content
 pref("accessibility.tabfocus_applies_to_xul", true);
-//@line 243 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 247 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("accessibility.usetexttospeech", "");
 pref("accessibility.usebrailledisplay", "");
@@ -320,8 +324,11 @@ pref("toolkit.scrollbox.clickToScroll.scrollDelay", 150);
 
 // Telemetry
 pref("toolkit.telemetry.enabled", false);
-// Telemetry test server to be used until the official one is public
-pref("toolkit.telemetry.server", "http://telemetry.allizom.org");
+pref("toolkit.telemetry.server", "https://data.mozilla.com");
+// Telemetry server owner. Please change if you set toolkit.telemetry.server to a different server
+pref("toolkit.telemetry.server_owner", "Mozilla");
+// Information page about telemetry (temporary ; will be about:telemetry in the end)
+pref("toolkit.telemetry.infoURL", "http://www.mozilla.com/legal/privacy/firefox.html#telemetry");
 
 // view source
 pref("view_source.syntax_highlight", true);
@@ -632,9 +639,9 @@ pref("dom.min_timeout_value", 4);
 pref("dom.min_background_timeout_value", 1000);
 
 // Parsing perf prefs. For now just mimic what the old code did.
-//@line 593 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 600 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("content.sink.pending_event_mode", 0);
-//@line 595 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 602 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable popups from plugins by default
 //   0 = openAllowed
@@ -649,7 +656,7 @@ pref("dom.event.contextmenu.enabled",       true);
 
 pref("javascript.enabled",                  true);
 pref("javascript.options.strict",           false);
-//@line 612 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 619 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("javascript.options.relimit",          true);
 pref("javascript.options.tracejit.content",  true);
 pref("javascript.options.tracejit.chrome",   true);
@@ -664,9 +671,9 @@ pref("javascript.options.methodjit_always", false);
 // Comment 32 and Bug 613551.
 pref("javascript.options.mem.high_water_mark", 128);
 pref("javascript.options.mem.max", -1);
-pref("javascript.options.mem.gc_frequency",   300);
 pref("javascript.options.mem.gc_per_compartment", true);
 pref("javascript.options.mem.log", false);
+pref("javascript.options.gc_on_memory_pressure", true);
 
 // advanced prefs
 pref("advanced.mailftp",                    false);
@@ -695,9 +702,9 @@ pref("network.protocol-handler.external.data", false);
 pref("network.protocol-handler.external.ms-help", false);
 pref("network.protocol-handler.external.shell", false);
 pref("network.protocol-handler.external.vnd.ms.radio", false);
-//@line 658 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 665 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.help", false);
-//@line 660 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 667 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.protocol-handler.external.disk", false);
 pref("network.protocol-handler.external.disks", false);
 pref("network.protocol-handler.external.afp", false);
@@ -748,7 +755,10 @@ pref("network.http.keep-alive.timeout", 115);
 // Note: the socket transport service will clamp the number below 256 if the OS
 // cannot allocate that many FDs, and it also always tries to reserve up to 250
 // file descriptors for things other than sockets.   
+// -- windows using lower limit until bug 692260 resolved
+//@line 721 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("network.http.max-connections", 256);
+//@line 723 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // limit the absolute number of http connections that can be established per
 // host.  if a http proxy server is enabled, then the "server" is the proxy
@@ -812,6 +822,10 @@ pref("network.http.qos", 0);
 // connection.
 pref("network.http.connection-retry-timeout", 250);
 
+// Disable IPv6 for backup connections to workaround problems about broken
+// IPv6 connectivity.
+pref("network.http.fast-fallback-to-IPv4", false);
+
 // default values for FTP
 // in a DSCP environment this should be 40 (0x28, or AF11), per RFC-4594,
 // Section 4.8 "High-Throughput Data Service Class", and 80 (0x50, or AF22)
@@ -847,9 +861,20 @@ pref("network.websocket.timeout.ping.request", 0);
 pref("network.websocket.timeout.ping.response", 10);
 
 // Defines whether or not to try and negotiate the stream-deflate compression
-// extension with the websocket server
+// extension with the websocket server. Stream-Deflate has been removed from
+// the standards track document, but can still be used by servers who opt
+// into it.
 pref("network.websocket.extensions.stream-deflate", false);
 
+// the maximum number of concurrent websocket sessions. By specification there
+// is never more than one handshake oustanding to an individual host at
+// one time.
+pref("network.websocket.max-connections", 200);
+
+// by default scripts loaded from a https:// origin can only open secure
+// (i.e. wss://) websockets.
+pref("network.websocket.allowInsecureFromHTTPS", false);
+
 // </ws>
 
 // Server-Sent Events
@@ -1036,7 +1061,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 1004 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1031 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Controls which NTLM authentication implementation we default to. True forces
 // the use of our generic (internal) NTLM authentication implementation vs. any
@@ -1131,7 +1156,56 @@ pref("intl.hyphenation-alias.en", "en-us");
 // and for other subtags of en-*, if no specific patterns are available
 pref("intl.hyphenation-alias.en-*", "en-us");
 
-pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Standard Symbols L, DejaVu Sans, Cambria Math");
+pref("intl.hyphenation-alias.af-*", "af");
+pref("intl.hyphenation-alias.bg-*", "bg");
+pref("intl.hyphenation-alias.ca-*", "ca");
+pref("intl.hyphenation-alias.cy-*", "cy");
+pref("intl.hyphenation-alias.da-*", "da");
+pref("intl.hyphenation-alias.eo-*", "eo");
+pref("intl.hyphenation-alias.es-*", "es");
+pref("intl.hyphenation-alias.et-*", "et");
+pref("intl.hyphenation-alias.fi-*", "fi");
+pref("intl.hyphenation-alias.fr-*", "fr");
+pref("intl.hyphenation-alias.gl-*", "gl");
+pref("intl.hyphenation-alias.hr-*", "hr");
+pref("intl.hyphenation-alias.hsb-*", "hsb");
+pref("intl.hyphenation-alias.ia-*", "ia");
+pref("intl.hyphenation-alias.is-*", "is");
+pref("intl.hyphenation-alias.kmr-*", "kmr");
+pref("intl.hyphenation-alias.la-*", "la");
+pref("intl.hyphenation-alias.lt-*", "lt");
+pref("intl.hyphenation-alias.mn-*", "mn");
+pref("intl.hyphenation-alias.nl-*", "nl");
+pref("intl.hyphenation-alias.pt-*", "pt");
+pref("intl.hyphenation-alias.ru-*", "ru");
+pref("intl.hyphenation-alias.sl-*", "sl");
+pref("intl.hyphenation-alias.sv-*", "sv");
+pref("intl.hyphenation-alias.uk-*", "uk");
+
+// use reformed (1996) German patterns by default unless specifically tagged as de-1901
+// (these prefs may soon be obsoleted by better BCP47-based tag matching, but for now...)
+pref("intl.hyphenation-alias.de", "de-1996");
+pref("intl.hyphenation-alias.de-*", "de-1996");
+pref("intl.hyphenation-alias.de-DE-1901", "de-1901");
+pref("intl.hyphenation-alias.de-CH-*", "de-CH");
+
+// patterns from TeX are tagged as "sh" (Serbo-Croatian) macrolanguage;
+// alias "sr" (Serbian) and "bs" (Bosnian) to those patterns
+// (Croatian has its own separate patterns).
+pref("intl.hyphenation-alias.sr", "sh");
+pref("intl.hyphenation-alias.bs", "sh");
+pref("intl.hyphenation-alias.sh-*", "sh");
+pref("intl.hyphenation-alias.sr-*", "sh");
+pref("intl.hyphenation-alias.bs-*", "sh");
+
+// Norwegian has two forms, Bokmål and Nynorsk, with "no" as a macrolanguage encompassing both.
+// For "no", we'll alias to "nb" (Bokmål) as that is the more widely used written form.
+pref("intl.hyphenation-alias.no", "nb");
+pref("intl.hyphenation-alias.no-*", "nb");
+pref("intl.hyphenation-alias.nb-*", "nb");
+pref("intl.hyphenation-alias.nn-*", "nn");
+
+pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Asana Math, Standard Symbols L, DejaVu Sans, Cambria Math");
 
 // Some CJK fonts have bad underline offset, their CJK character glyphs are overlapped (or adjoined)  to its underline.
 // These fonts are ignored the underline offset, instead of it, the underline is lowered to bottom of its em descent.
@@ -1420,20 +1494,20 @@ pref("editor.positioning.offset",            0);
 pref("dom.max_chrome_script_run_time", 20);
 pref("dom.max_script_run_time", 10);
 
-//@line 1388 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1464 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 // How long a plugin is allowed to process a synchronous IPC message
 // before we consider it "hung".
 pref("dom.ipc.plugins.timeoutSecs", 45);
 // How long a plugin launch is allowed to take before
 // we consider it failed.
 pref("dom.ipc.plugins.processLaunchTimeoutSecs", 45);
-//@line 1399 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1475 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Disable oopp for standard java. They run their own process isolation (which
 // conflicts with our implementation, at least on Windows).
 pref("dom.ipc.plugins.java.enabled", false);
 
-//@line 1414 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1490 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 pref("svg.smil.enabled", true);
 
@@ -1470,9 +1544,9 @@ pref("font.minimum-size.x-western", 0);
 pref("font.minimum-size.x-unicode", 0);
 pref("font.minimum-size.x-user-def", 0);
 
-//@line 1910 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1992 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 1912 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 1994 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 // Mac specific preference defaults
 pref("browser.drag_out_of_frame_style", 1);
 pref("ui.key.saveLink.shift", false); // true = shift, false = meta
@@ -1862,7 +1936,7 @@ pref("font.size.variable.zh-HK", 15);
 pref("font.size.fixed.zh-HK", 16);
 
 // Apple's Symbol is Unicode so use it
-pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Symbol, DejaVu Sans, Cambria Math");
+pref("font.mathfont-family", "STIXNonUnicode, STIXSizeOneSym, STIXSize1, STIXGeneral, Asana Math, Symbol, DejaVu Sans, Cambria Math");
 
 // individual font faces to be treated as independent families
 // names are Postscript names of each face
@@ -1902,17 +1976,17 @@ pref("mousewheel.system_scroll_override_on_root_content.enabled", false);
 // Macbook touchpad two finger pixel scrolling
 pref("mousewheel.enable_pixel_scrolling", true);
 
-//@line 2343 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2425 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2543 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2625 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 2812 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 2894 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3087 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3169 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3107 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3189 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
-//@line 3115 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3197 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Login Manager prefs
 pref("signon.rememberSignons",              true);
@@ -1966,13 +2040,17 @@ pref("image.mem.decodeondraw", false);
 // Minimum timeout for image discarding (in milliseconds). The actual time in
 // which an image must inactive for it to be discarded will vary between this
 // value and twice this value.
-pref("image.mem.min_discard_timeout_ms", 120000);
+//
+// This used to be 120 seconds, but having it that high causes our working
+// set to grow very large. Switching it back to 10 seconds will hopefully
+// be better.
+pref("image.mem.min_discard_timeout_ms", 10000);
 
 // Chunk size for calls to the image decoders
-pref("image.mem.decode_bytes_at_a_time", 200000);
+pref("image.mem.decode_bytes_at_a_time", 4096);
 
 // The longest time we can spend in an iteration of an async decode
-pref("image.mem.max_ms_before_yield", 400);
+pref("image.mem.max_ms_before_yield", 5);
 
 // The maximum source data size for which we auto sync decode
 pref("image.mem.max_bytes_for_sync_decode", 150000);
@@ -1986,17 +2064,17 @@ pref("webgl.osmesalib", "");
 pref("webgl.verbose", false);
 pref("webgl.prefer-native-gl", false);
 
-//@line 3194 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
-
-//@line 3199 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3278 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to disable acceleration for all widgets.
+//@line 3283 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 pref("layers.acceleration.disabled", false);
+//@line 3285 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Whether to force acceleration on, ignoring blacklists.
 pref("layers.acceleration.force-enabled", false);
 
-//@line 3218 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
+//@line 3303 "/builds/slave/m-beta-osx64-xr/build/modules/libpref/src/init/all.js"
 
 // Enable/Disable the geolocation API for content
 pref("geo.enabled", true);
@@ -2031,3 +2109,6 @@ pref("network.buffer.cache.size",  32768);
 
 // Desktop Notification
 pref("notification.feature.enabled", false);
+
+//3D Transforms
+pref("layout.3d-transforms.enabled, false);
